pub struct MqttLastWill {
pub topic: String,
pub qos: u8,
pub message: String,
pub retain: bool,
}Expand description
Mqtt last will structure
Fields
topic: StringThe topic where the Last Will and Testament message will be sent.
qos: u8Defines how hard the broker/client will try to ensure that the Last Will and Testament message is received. Its value MUST be either 0, 1 or 2.
message: StringLast Will message.
retain: boolWhether the broker should retain the Last Will and Testament message or not.