pub struct MqttServerBindings {
pub client_id: Option<String>,
pub clean_session: Option<bool>,
pub last_will: Option<MqttLastWill>,
pub keep_alive: Option<u32>,
pub session_expiry_interval: Option<MqttBindingNumValue>,
pub max_packet_size: Option<MqttBindingNumValue>,
pub binding_version: Option<String>,
}Expand description
Mqtt server binding
Fields
client_id: Option<String>The client identifier.
clean_session: Option<bool>Whether to create a persistent connection or not. When false, the connection will be persistent. This is called clean start in MQTTv5.
last_will: Option<MqttLastWill>Last Will and Testament configuration. topic, qos, message and retain are properties of this object as shown below.
keep_alive: Option<u32>Interval in seconds of the longest period of time the broker and the client can endure without sending a message.
session_expiry_interval: Option<MqttBindingNumValue>Interval in seconds or a Schema Object containing the definition of the interval. The broker maintains a session for a disconnected client until this interval expires.
max_packet_size: Option<MqttBindingNumValue>Number of bytes or a Schema Object representing the maximum packet size the client is willing to accept.
binding_version: Option<String>The version of this binding. If omitted, “latest” MUST be assumed.