pub struct MqttMessageBindings {
pub payload_format_indicator: Option<u8>,
pub correlation_data: Option<Schema>,
pub content_type: Option<String>,
pub response_topic: Option<MqttResponseTopic>,
pub binding_version: Option<String>,
}Expand description
Mqtt message bindings
Fields
payload_format_indicator: Option<u8>Either: 0 (zero): Indicates that the payload is unspecified bytes, or 1: Indicates that the payload is UTF-8 encoded character data.
correlation_data: Option<Schema>Correlation Data is used by the sender of the request message to identify which request the response message is for when it is received.
content_type: Option<String>String describing the content type of the message payload. This should not conflict with the contentType field of the associated AsyncAPI Message object.
response_topic: Option<MqttResponseTopic>The topic (channel URI) for a response message.
binding_version: Option<String>The version of this binding. If omitted, “latest” MUST be assumed.